<?php

namespace App\Http\Controllers\Backend;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class AuthController extends Controller
{
    public function login()
    {
        if (Auth::check()) {
            if (Auth::user()->role === 'cms') {
                return redirect('/admin/dashboard');
            }
            if (Auth::user()->role === 'user') {
                return redirect('/user-dashboard');
            }
            return abort(401);
        }

        return view('backend.auth.login');
    }

    public function signIn(Request $request)
    {
        $request->validate([
            'email' => 'required|exists:users,email',
            'password' => 'required'
        ]);

        $credentials = [
            'email' => $request->email,
            'password' => $request->password,
        ];

        if (Auth::attempt($credentials)) {
            $user = Auth::user();

            // Check the user's role and redirect accordingly
            if ($user->role === 'cms') {
                return redirect('admin/dashboard');
            } elseif ($user->role === 'user') {
                return redirect('user-dashboard');
            } elseif ($user->role === 'recruiter') {
                return redirect('recruiter-dashboard');
            }
        } else {
            return back()->with('error', 'Your credentials are incorrect.');
        }
    }
    public function logout(Request $request)
    {
        Auth::logout();
        return redirect('/');
    }
}
