<?php

namespace App\Http\Controllers;

use App\Models\Career;
use App\Models\Category;
use App\Models\Application;
use App\Models\ApplicationCareer;
use App\Models\CareerLevel;
use App\Models\Requirement;
use Illuminate\Http\Request;
use App\Models\Qualification;
use App\Models\YearOfExperience;
use App\Models\JobResponsibility;
use App\Models\JobSpecialization;
use App\Models\ApplicationCareerStatus;

class CareerController extends Controller
{

    public function index()
    {
        $careers = Career::with('applications') // Assuming you have a relationship set up for applications
            ->orderBy('id', 'DESC')
            ->get();

        return view('backend.modules.careers.index', compact('careers'));
    }

    public function viewApplicants($id)
    {
        $career = Career::with('applications')->findOrFail($id);

        return view('backend.modules.careers.applicants', compact('career'));
    }


    public function create()
    {
        return view('backend.modules.careers.create');
    }

    public function store(Request $request)
    {
        // Validate the incoming data
        $validatedData = $request->validate([
            'category_name' => 'required|string|max:255',
            'jobtitle' => 'required|string|max:255',
            'job_type' => 'required|string|max:255',
            'work_schedule' => 'required|string|max:255',
            'subtitle' => 'required|string|max:255',
            'rate' => 'required|string',
            'location' => 'required|string|max:255',
            'description' => 'required|string',
            'job_responsibilities.*' => 'required|string',
            'requirements.*' => 'required|string',
            'career_level.*' => 'required|string|max:255',
            'year_of_experience.*' => 'required|string',
            'job_specialization.*' => 'required|string|max:255',
            'qualification.*' => 'required|string|max:255',
        ]);

        // Create the Category
        $category = Category::create(['category_name' => $validatedData['category_name']]);

        // Create the Career
        $career = Career::create([
            'jobtitle' => $validatedData['jobtitle'],
            'job_type' => $validatedData['job_type'],
            'work_schedule' => $validatedData['work_schedule'],
            'subtitle' => $validatedData['subtitle'],
            'rate' => $validatedData['rate'],
            'location' => $validatedData['location'],
            'description' => $validatedData['description'],
            'category_id' => $category->id,
        ]);

        // Create Job Responsibilities
        foreach ($validatedData['job_responsibilities'] as $responsibility) {
            JobResponsibility::create([
                'career_id' => $career->id,
                'job_responsibility' => $responsibility,
            ]);
        }

        // Create Requirements
        foreach ($validatedData['requirements'] as $requirement) {
            Requirement::create([
                'career_id' => $career->id,
                'requirement' => $requirement,
            ]);
        }

        // Create Career Levels
        foreach ($validatedData['career_level'] as $level) {
            CareerLevel::create([
                'career_id' => $career->id,
                'career_level' => $level,
            ]);
        }

        // Create Years of Experience
        foreach ($validatedData['year_of_experience'] as $experience) {
            YearOfExperience::create([
                'career_id' => $career->id,
                'year_of_experience' => $experience,
            ]);
        }

        // Create Job Specializations
        foreach ($validatedData['job_specialization'] as $specialization) {
            JobSpecialization::create([
                'career_id' => $career->id,
                'job_specialization' => $specialization,
            ]);
        }

        // Create Qualifications
        foreach ($validatedData['qualification'] as $qual) {
            Qualification::create([
                'career_id' => $career->id,
                'qualification' => $qual,
            ]);
        }

        return redirect()->route('careers.index')->with('success', 'Career created successfully.');
    }


    public function show($id)
    {
        //
    }


    public function edit($id)
    {
        // Find the career by ID
        $career = Career::with(['responsibilities', 'requirements', 'levels', 'yearsOfExperience', 'specializations', 'qualifications'])->findOrFail($id);

        // Get categories for the select input
        $categories = Category::all();

        return view('backend.modules.careers.edit', compact('career', 'categories'));
    }

    public function update(Request $request, $id)
    {
        // Validate the incoming data
        $validatedData = $request->validate([
            'category_name' => 'required|string|max:255',
            'jobtitle' => 'required|string|max:255',
            'job_type' => 'required|string|max:255',
            'work_schedule' => 'required|string|max:255',
            'subtitle' => 'required|string|max:255',
            'rate' => 'required|string',
            'location' => 'required|string|max:255',
            'description' => 'required|string',
            'job_responsibilities.*' => 'required|string',
            'requirements.*' => 'required|string',
            'career_level.*' => 'required|string|max:255',
            'year_of_experience.*' => 'required|string',
            'job_specialization.*' => 'required|string|max:255',
            'qualification.*' => 'required|string|max:255',
        ]);

        // Find the career and update its basic info
        $career = Career::findOrFail($id);
        $career->update([
            'jobtitle' => $validatedData['jobtitle'],
            'job_type' => $validatedData['job_type'],
            'work_schedule' => $validatedData['work_schedule'],
            'subtitle' => $validatedData['subtitle'],
            'rate' => $validatedData['rate'],
            'location' => $validatedData['location'],
            'description' => $validatedData['description'],
        ]);

        // Update Job Responsibilities
        $career->responsibilities()->delete(); // Remove existing responsibilities
        foreach ($validatedData['job_responsibilities'] as $responsibility) {
            JobResponsibility::create([
                'career_id' => $career->id,
                'job_responsibility' => $responsibility,
            ]);
        }

        // Update Requirements
        $career->requirements()->delete(); // Remove existing requirements
        foreach ($validatedData['requirements'] as $requirement) {
            Requirement::create([
                'career_id' => $career->id,
                'requirement' => $requirement,
            ]);
        }

        // Update Career Levels
        $career->levels()->delete(); // Remove existing career levels
        foreach ($validatedData['career_level'] as $level) {
            CareerLevel::create([
                'career_id' => $career->id,
                'career_level' => $level,
            ]);
        }

        // Update Years of Experience
        $career->yearsOfExperience()->delete(); // Remove existing years of experience
        foreach ($validatedData['year_of_experience'] as $experience) {
            YearOfExperience::create([
                'career_id' => $career->id,
                'year_of_experience' => $experience,
            ]);
        }

        // Update Job Specializations
        $career->specializations()->delete(); // Remove existing job specializations
        foreach ($validatedData['job_specialization'] as $specialization) {
            JobSpecialization::create([
                'career_id' => $career->id,
                'job_specialization' => $specialization,
            ]);
        }

        // Update Qualifications
        $career->qualifications()->delete(); // Remove existing qualifications
        foreach ($validatedData['qualification'] as $qual) {
            Qualification::create([
                'career_id' => $career->id,
                'qualification' => $qual,
            ]);
        }

        return redirect()->route('careers.index')->with('success', 'Career updated successfully.');
    }


    public function destroy($id)
    {
        $careers = Career::findOrFail($id);
        $careers->delete();

        return redirect()->route('careers.index');
    }

    public function hireApplicant($id)
    {
        // Find the application by ID
        $applicant = ApplicationCareer::find($id);

        $recruiterId = auth()->user()->id;

        ApplicationCareerStatus::create([
            'application_career_id' => $applicant->id, // Assuming pivot ID is what you want to save
            'status' => "For Review",
            'recruiter_id' => $recruiterId // Store the recruiter's ID here
        ]);

        return redirect()->route('view.hired.applicants')->with('success', 'Applicant hired successfully.');
    }


    public function viewHiredApplicants()
    {
        $recruiterId = auth()->user()->id; // Get the logged-in recruiter's ID

        $applications = Application::with(['applicationCareer.career', 'applicationCareer.applicationCareerStatus'])
            ->whereHas('applicationCareer.applicationCareerStatus', function ($query) use ($recruiterId) {
                $query->where('recruiter_id', $recruiterId);
            })
            ->get();

        return view('frontend.pages.recruiter-hired-applicants', compact('applications'));
    }
}
