<?php

namespace App\Http\Controllers;

use App\Models\Career;
use Illuminate\Http\Request;

class ChatbotController extends Controller
{
    public function sendMessage(Request $request)
    {
        $userMessage = strtolower($request->input('message'));

        // Call the method that checks for career-related queries
        $botResponse = $this->getChatbotResponse($userMessage);

        return response()->json([
            'response' => $botResponse
        ]);
    }

    // Determine the chatbot response based on the user's input
    private function getChatbotResponse($message)
    {
        // Check for job-related keywords and fetch job listings accordingly
        if (strpos($message, 'job') !== false || strpos($message, 'position') !== false) {
            return $this->getCareerListings();
        }

        // Default responses for other queries
        $responses = [
            'hello' => 'Greetings! How can I assist you with your job search today? Here are some options you might find helpful:\n1. Available Job Listings\n2. Job Categories\n3. Application Process',
            'bye' => 'Thank you for reaching out! Wishing you the best in your job search. Goodbye!',
            'available job listings' => $this->getCareerListings(),
            'job categories' => $this->getJobCategories(), // New method for job categories
            'application process' => 'The application process typically involves submitting your resume, filling out an application form, and participating in interviews. If you need more specific details, please let me know!',
            'default' => 'I apologize, but I didn’t quite understand your request. Please feel free to ask about available job listings, job categories, or the application process.'
        ];

        foreach ($responses as $keyword => $reply) {
            if (strpos($message, $keyword) !== false) {
                return $reply;
            }
        }

        return $responses['default'];
    }

    // Search career listings based on the user's message
    private function getCareerListings()
    {
        // Fetch all available jobs
        $careers = Career::all();

        // If jobs are found, return the listings
        if ($careers->count() > 0) {
            $response = "Here are some available job opportunities:\n";
            foreach ($careers as $career) {
                $response .= "- **" . $career->jobtitle . "** at **" . $career->location . "** (" . ucfirst($career->job_type) . ")\n";
            }
            // Prompt for more questions with options
            $response .= "\nIf you're interested, you may wish to:\n1. Learn more about job categories\n2. Inquire about a specific position\n3. Exit the conversation";
            return $response;
        } else {
            // If no jobs are found
            return "I regret to inform you that no job opportunities are currently available. Would you like to explore another category or exit the conversation?";
        }
    }

    // New method for job categories
    private function getJobCategories()
    {
        // Example categories - this would usually come from your database or predefined list
        $categories = [
            'Engineering',
            'Marketing',
            'Sales',
            'Finance',
            'Human Resources',
            'IT Support'
        ];

        $response = "Here are the available job categories:\n";
        foreach ($categories as $category) {
            $response .= "- " . $category . "\n";
        }

        return $response . "\nIf you'd like to know more about a specific category or have other questions, feel free to ask!";
    }
}
