<?php

namespace App\Http\Controllers;

use App\Models\Services;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class ServicesController extends Controller
{

    public function index()
    {
        $services = Services::orderBy('id', 'DESC')->get();


        return view('backend.modules.services.index', compact('services'));
    }

    public function create()
    {
        return view('backend.modules.services.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'title' => 'nullable|string',
            'subtitle' => 'nullable|string',
            'description' => 'nullable',
            'image' => 'nullable|image'
        ]);

        $services = Services::create([
            'title' => $request->input('title'),
            'subtitle' => $request->input('subtitle'),
            'description' => $request->input('description'),
        ]);

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            $services->update(['image' => 'images/uploads/' . $imageName]);
        }

        return redirect()->route('services.index');
    }


    public function show($id)
    {
        //
    }


    public function edit($id)
    {
        $services = Services::findOrFail($id);

        return view('backend.modules.services.edit', compact('services'));
    }
    public function update(Request $request, $id)
    {
        $request->validate([
            'title' => 'nullable|string',
            'subtitle' => 'nullable|string',
            'description' => 'nullable|string',
            'image' => 'nullable|image|max:2048',
        ]);

        $services = Services::findOrFail($id);

        $updateData = [
            'title' => $request->input('title'),
            'subtitle' => $request->input('subtitle'),
            'description' => $request->input('description'),
        ];

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '_' . $image->getClientOriginalName();
            $image->move(public_path('images/uploads'), $imageName);
            $updateData['image'] = 'images/uploads/' . $imageName;
        }
        // Update the banner record
        $services->update($updateData);

        return redirect()->route('services.index');
    }


    public function destroy($id)
    {
        $services = Services::findOrFail($id);
        $services->delete();

        return redirect()->route('services.index');
    }
}
