<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Application extends Model
{
    use HasFactory;

    protected $table = 'applications';

    protected $fillable = [
        'career_id',
        'recruiter_id',
        'user_id',
        'first_name',
        'last_name',
        'middle_name',
        'suffix',
        'sex',
        'religion',
        'birth_date',
        'birth_place',
        'email',
        'phone_no',
        'home_address',
        'city',
        'province',
        'region',
        'education',
        'degree',
        'tesda',
        'employment_status',
        'question_1',
        'question_2',
        'question_3',
        'status'
    ];
    public function applicationCareer()
    {
        return $this->hasMany(ApplicationCareer::class, 'application_id', 'id'); // Assuming 'id' is the primary key
    }

    // Relationship with WorkExperience
    public function workExperiences()
    {
        return $this->hasMany(WorkExperience::class, 'application_id');
    }

    // Relationship with Career
    public function career()
    {
        return $this->belongsTo(Career::class, 'career_id');
    }
    public function careers()
    {
        return $this->belongsToMany(Career::class, 'application_career')->withPivot('id');;
    }

    public function applicationCareerStatus()
    {
        return $this->hasMany(ApplicationCareerStatus::class, 'application_id');
    }


    public function careerStatus()
    {
        return $this->hasMany(ApplicationCareerStatus::class, 'application_career_id');
    }
    public function recruiter()
    {
        return $this->belongsTo(User::class);
    }
    public function applicationCareers()
    {
        return $this->hasMany(ApplicationCareer::class);
    }


    public static function hired_applicants($recruiter_id)
    {
        return Application::select(
            'applications.first_name',
            'applications.last_name',
            'applications.middle_name',
            'applications.phone_no',
            'applications.email',
            'careers.jobtitle',
        )
            ->join('users', 'applications.user_id', '=', 'users.id')
            ->join('careers', 'applications.career_id', '=', 'careers.id')
            ->join('application_career', 'applications.id', '=', 'application_career.application_id')
            ->join('application_career_status', 'application_career.id', '=', 'application_career_status.application_career_id')

            ->get();
    }
}
