<?php

use BotMan\BotMan\BotMan;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\UsersController;
use App\Http\Controllers\BannerController;
use App\Http\Controllers\CareerController;
use App\Http\Controllers\ChatbotController;
use BotMan\BotMan\Messages\Incoming\Answer;
use App\Http\Controllers\ResponseController;
use App\Http\Controllers\ServicesController;
use App\Http\Controllers\ContactUsController;
use App\Http\Controllers\ApplicationController;
use App\Http\Controllers\Backend\AuthController;
use App\Http\Controllers\Frontend\PageController;
use App\Http\Controllers\Backend as BackendController;
use App\Http\Controllers\Frontend as FrontendController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', [PageController::class, 'careers'])->name('careers');
Route::get('/application-form', [PageController::class, 'applicationForm']);
Route::post('/application-form', [ApplicationController::class, 'storeStep1'])->name('application.storeStep1');

Route::get('/application-form-2', [PageController::class, 'applicationForm2'])->name('application.step2');
Route::post('/application-form-2', [ApplicationController::class, 'storeStep2'])->name('application.storeStep2');

Route::get('/application-form-3', [PageController::class, 'applicationForm3'])->name('application.step3');
Route::post('/application-form-3', [ApplicationController::class, 'storeStep3'])->name('application.storeStep3');

Route::get('/careers/search/{id}', [PageController::class, 'careerSearch'])->name('careers.search');
Route::get('/careers/{id}', [PageController::class, 'careerSearch']);
Route::get('/careers', [PageController::class, 'search'])->name('career.search');
Route::get('/user-login', [PageController::class, 'login']);
Route::get('/about', [PageController::class, 'about']);
Route::get('/services', [PageController::class, 'services']);
Route::get('/services_details/{id}', [PageController::class, 'services_details']);
Route::get('/janitorial', [PageController::class, 'janitorial']);
Route::get('/outsourcing', [PageController::class, 'outsourcing']);
Route::get('/manufacturing', [PageController::class, 'manufacturing']);
Route::get('/contact', [PageController::class, 'contact']);

Route::get('/success', [App\Http\Controllers\ResponseController::class, 'success'])->name('success');
Route::get('/error', [App\Http\Controllers\ResponseController::class, 'error'])->name('error');

Route::post('/submit-form', [ContactUsController::class, 'store'])->name('form.submit');
Route::get('/careers/{id}/applicants', [CareerController::class, 'viewApplicants'])->name('careers.applicants');
Route::patch('/update-status/{applicationCareer}', [ApplicationController::class, 'updateStatus'])->name('update-status');

Route::post('/save-application', [ApplicationController::class, 'saveApplication'])->name('save.application');
Route::post('/hire-applicant/{id}', [CareerController::class, 'hireApplicant'])->name('hire.applicant');
Route::get('/hired-applicants', [CareerController::class, 'viewHiredApplicants'])->name('view.hired.applicants');
// AUTH CMS ACCESS
Route::get('/admin/login', [BackendController\AuthController::class, 'login'])->name('admin.login');
Route::post('/admin/login', [BackendController\AuthController::class, 'signIn'])->name('admin.signin');
// DEFAULT AUTH ROUTES
Auth::routes();

// AUTH USER ACCESS
Route::post('/user/change-password', [PageController::class, 'changePassword'])->name('user.change-password');
Route::get('/user-change-password', [PageController::class, 'user_change_password'])->name('user.dashboard');

Route::post('user/logout', [BackendController\AuthController::class, 'logout'])->name('user.logout');

Route::post('/chatbot/send', [ChatbotController::class, 'sendMessage']);

Route::middleware(['auth', 'user-access:user'])->group(function () {
    Route::get('/user-dashboard', [PageController::class, 'user_dashboard'])->name('user.dashboard');
});

Route::middleware(['auth', 'user-access:recruiter'])->group(function () {
    Route::get('/recruiter-dashboard', [PageController::class, 'recruiter_dashboard']);
    Route::get('/recruiter-applicants/{id}', [PageController::class, 'Applicants']);
    Route::get('/recruiter-applicants-details/{id}/{career_id}', [PageController::class, 'applicants_details']);
});

Route::prefix('admin')->middleware(['auth', 'user-access:cms'])->group(function () {
    Route::resource('/services', ServicesController::class);
    Route::resource('/banner', BannerController::class);
    Route::resource('/careers', CareerController::class);
    Route::resource('/contacts', ContactUsController::class);
    Route::resource('/applications', ApplicationController::class);
    Route::resource('/users', UsersController::class);

    Route::post('/logout', [BackendController\AuthController::class, 'logout'])->name('admin.logout');

    Route::get('/dashboard', function () {
        return view('backend.modules.dashboard.index');
    });
});
